@@ -46,7 +46,6 @@ function(x) {
 	rval
 }
 
-
 umf_terms2formulalist <- 
 function(termNames, opt, replaceInt = "(1)") {
 	i <- termNames %in% opt$interceptLabel
@@ -98,15 +97,11 @@ function(x, intercept = FALSE, ...) {
 	sn1[j] <- shortnames[j != 0L]
 	shortnames <- sn1
 	term.prefix <- specs["estimate:short.name", ]
-	
-	#print(rbind(names(shortnames), shortnames, specs["estimate:itemName", ]))
-	#cat("--\n")
-	#return(invisible())
 	term.prefix[] <- shortnames
 	term.prefix[i] <- names(term.prefix)[i <- is.na(term.prefix)]
 	
 	if(is(x, "unmarkedFitDS")) {
-		if(!is.na(term.prefix['p'])) {
+		if(!anyNA(term.prefix['p'])) {
 			z <- allterms[[ i <- which(names(term.prefix) == "p") ]]
 			detprefix <- switch(x@keyfun, uniform = "", halfnorm = "sigma",
 				hazard = "shape", exp = "rate", "")
