@@ -4,14 +4,13 @@ function(model) {
 	std.coef(model, FALSE)
 }
 
-
 .vif <-
 function(x) {
 	v <- vcov(x)
 	nam <- dimnames(v)[[1L]]
 	if(dim(v)[1L] < 2L) return(structure(rep_len(1, dim(v)[1L]),
 										 names = dimnames(v)[[1L]]))
-	if ((ndef <- sum(is.na(coeffs(x)))) > 0L) 
+	if ((ndef <- sum(is.na(coef(x)))) > 0L) 
         stop(sprintf(ngettext(ndef, "one coefficient is not defined",
 			"%d coefficients are not defined"), ndef))
 	o <- attr(model.matrix(x), "assign")
@@ -28,11 +27,12 @@ function(x) {
 
 .partialsd <-
 function(x, sd, vif, n, p = length(x) - 1) {
-	sd * sqrt(1 / vif) * sqrt((n - 1)/(n - p))
+	sd * sqrt(1 / vif) * sqrt((n - 1) / (n - p))
 }
 
 partial.sd <- function(x) {
 	mm <- model.matrix(x)
+	m <- ncol(mm)
 	.partialsd(coef(x), apply(mm, 2L, sd), .vif(x), nobs(x),
 			   sum(attr(mm, "assign") != 0))
 }
@@ -53,5 +53,3 @@ function(x, partial.sd, ...) {
 	colnames(coefmat)[1L:2L] <- c("Estimate*", "Std. Error*")
 	return (coefmat)
 }
-
-
